! Generates the data of Figure 8 (a)
! Run: $ gfortran  fig_8a.f90; ./a.out
!
! Author: Michele Mugnaine
! Last modified: 27/06/2023
!________________________________________________________________________________________
PROGRAM MAIN
  IMPLICIT NONE
  REAL*8::theta0,psi0,thetan,psin,P,q,psim,a
  INTEGER::i,n,ic
  REAL*8,PARAMETER:: pi=4.0*ATAN(1.0)
  REAL*8, PARAMETER:: K=2.0,q0=3.0,q1=6.0,qm=1.5 !Parameters from the Revtokamap
  INTEGER, PARAMETER:: nmax=26, nfinal=1E4 ! Number of ICs and iterations, respectively
  !--------------------------------------------------------------------------------------
  OPEN(1,FILE='IC_8a.dat',STATUS='OLD')
  OPEN(2,FILE='Data_8a.dat',STATUS='UNKNOWN')
  !--------------------------------------------------------------------------------------
  ! Values of a and Psim
  psim=1.0/(1.0+SQRT((1.0-qm/q1)/(1.0-qm/q0))) ! Equation (135)
  a=(1.0-(qm/q0))/(psim**2.0)
  !
  ! Initial Conditions
  DO i=1,nmax
     READ(1,*) theta0,psi0,ic
     ! ic is an index to attribute color to the solutions
     !
     TIME: DO n=1,nfinal ! Iteration of the map
        P=psi0-1.0-K/(2.0*pi)*SIN(2.0*pi*theta0) ! Function P - Equation (131)
        !
        psin=1.0/2.0*(P+SQRT(P**2.0+4.0*psi0))
        q=qm/(1.0-a*(psin-psim)**2.0) ! q-profile
        !
        thetan=MOD(theta0+1.0/q-(K*COS(2.0*pi*theta0))/((2.0*pi)**2.0*(1.0+psin)**2.0),1.0)
        IF(thetan.LT.0.0) thetan=thetan+1.0
        !
        IF(psin.LT.1.1) WRITE(2,*) thetan,psin,ic
        !
        psi0=psin; theta0=thetan
     END DO TIME
  END DO
END PROGRAM MAIN
  
