! Generates the data of Figure 8 (b)
! Run: $ gfortran  fig_8b.f90; ./a.out
!
! Author: Michele Mugnaine
! Last modified: 27/06/2023
!________________________________________________________________________________________
PROGRAM MAIN
  IMPLICIT NONE
  REAL*8::theta0,psi0,thetan,psin,P,q,psim,a,sum,nwn,psi00
  INTEGER::i,n
  REAL*8,PARAMETER:: pi=4.0*ATAN(1.0)
  REAL*8, PARAMETER:: K=2.0,q0=3.0,q1=6.0,qm=1.5 !Parameters from the Revtokamap
  INTEGER, PARAMETER:: nmax=1E3, nfinal=1E5 ! Number of ICs and iterations, respectively
  !--------------------------------------------------------------------------------------
  OPEN(1,FILE='Data_8b.dat',STATUS='UNKNOWN')
  !--------------------------------------------------------------------------------------
  ! Values of a and Psim
  psim=1.0/(1.0+SQRT((1.0-qm/q1)/(1.0-qm/q0))) ! Equation (135)
  a=(1.0-(qm/q0))/(psim**2.0)
  !
  ! Initial Conditions
  IC: DO i=1,nmax
     theta0=0.5
     psi00=1.0*i/(1.0*nmax)
     psi0=psi00
     !
     ! Auxiliary variables for the computation of the limit for the winding number
     sum=0.0; nwn=0.0 
     !
     TIME: DO n=1,nfinal ! Iteration of the map
        P=psi0-1.0-K/(2.0*pi)*SIN(2.0*pi*theta0) ! Function P - Equation (131)
        !
        psin=1.0/2.0*(P+SQRT(P**2.0+4.0*psi0))
        q=qm/(1.0-a*(psin-psim)**2.0) ! q-profile
        !
        thetan=theta0+1.0/q-(K*COS(2.0*pi*theta0))/((2.0*pi)**2.0*(1.0+psin)**2.0)
        !
         ! Convergence test for the limit
        IF(n.GT.nfinal/2) THEN
           nwn=nwn+1.0
           sum=sum+thetan/(1.0*n)
        END IF
        !
        psi0=psin; theta0=thetan
     END DO TIME
     ! If the limit converges, the winding number exist
     IF(ABS(sum/nwn-thetan/(1.0*nfinal)).LT.5E-5) WRITE(1,*) psi00,thetan/(1.0*nfinal)
  END DO IC
END PROGRAM MAIN
  
